@@ -362,7 +362,10 @@ class File(Path):
     def type(self):
         return self._name.type
 
-    def mode(self):
+    def get_mode(self):
+        # Changed name from mode so as not to break pandas read.
+        # TODO: Use common .mode variable to indicate mode
+        # Apparently, that's the way to do it
         return self._name.mode
 
     def set_mode_binary(self):
@@ -474,8 +477,8 @@ class File(Path):
                 data = Crypt.encrypt(data, crypt_key)
                 self._write(data, mode='wb')
             else:
-                if mode and self.mode():
-                    mode = mode + self.mode()
+                if mode and self.get_mode():
+                    mode = mode + self.get_mode()
                 self._write(data, mode=mode)
 
     def _write(self, data, mode='w'):
@@ -557,7 +560,7 @@ class File(Path):
                 if 'b' not in mode:
                     data = data.decode()
             else:
-                mode = mode + self.mode()
+                mode = mode + self.get_mode()
                 data = self._read(mode=mode,
                                   num_lines=num_lines)
 
